# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateMedicalContraindication(BaseModel):
    update_medical_contraindication: Optional[
        "UpdateMedicalContraindicationUpdateMedicalContraindication"
    ] = Field(alias="updateMedicalContraindication")


class UpdateMedicalContraindicationUpdateMedicalContraindication(BaseModel):
    id: str
    name: str


UpdateMedicalContraindication.model_rebuild()
