# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryBoxFolders(BaseModel):
    box_folders: Optional["QueryBoxFoldersBoxFolders"] = Field(alias="boxFolders")


class QueryBoxFoldersBoxFolders(BaseModel):
    results: Optional[List[Optional["QueryBoxFoldersBoxFoldersResults"]]]


class QueryBoxFoldersBoxFoldersResults(BaseModel):
    folder_name: Optional[str] = Field(alias="folderName")
    folder_id: Optional[str] = Field(alias="folderId")


QueryBoxFolders.model_rebuild()
QueryBoxFoldersBoxFolders.model_rebuild()
