# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateMedicalCondition(BaseModel):
    create_medical_condition: Optional[
        "CreateMedicalConditionCreateMedicalCondition"
    ] = Field(alias="createMedicalCondition")


class CreateMedicalConditionCreateMedicalCondition(BaseModel):
    id: str
    name: str


CreateMedicalCondition.model_rebuild()
