# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountSoftwares(BaseModel):
    count_softwares: Optional["CountSoftwaresCountSoftwares"] = Field(
        alias="countSoftwares"
    )


class CountSoftwaresCountSoftwares(BaseModel):
    count: Optional[Any]


CountSoftwares.model_rebuild()
