# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllMedicalGuidelines(BaseModel):
    delete_all_medical_guidelines: Optional[
        List[Optional["DeleteAllMedicalGuidelinesDeleteAllMedicalGuidelines"]]
    ] = Field(alias="deleteAllMedicalGuidelines")


class DeleteAllMedicalGuidelinesDeleteAllMedicalGuidelines(BaseModel):
    id: str
    state: EntityState


DeleteAllMedicalGuidelines.model_rebuild()
