# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteSoftwares(BaseModel):
    delete_softwares: Optional[List[Optional["DeleteSoftwaresDeleteSoftwares"]]] = (
        Field(alias="deleteSoftwares")
    )


class DeleteSoftwaresDeleteSoftwares(BaseModel):
    id: str
    state: EntityState


DeleteSoftwares.model_rebuild()
