# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateMedicalIndication(BaseModel):
    update_medical_indication: Optional[
        "UpdateMedicalIndicationUpdateMedicalIndication"
    ] = Field(alias="updateMedicalIndication")


class UpdateMedicalIndicationUpdateMedicalIndication(BaseModel):
    id: str
    name: str


UpdateMedicalIndication.model_rebuild()
