# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryDiscordChannels(BaseModel):
    discord_channels: Optional["QueryDiscordChannelsDiscordChannels"] = Field(
        alias="discordChannels"
    )


class QueryDiscordChannelsDiscordChannels(BaseModel):
    results: Optional[List[Optional["QueryDiscordChannelsDiscordChannelsResults"]]]


class QueryDiscordChannelsDiscordChannelsResults(BaseModel):
    channel_name: Optional[str] = Field(alias="channelName")
    channel_id: Optional[str] = Field(alias="channelId")


QueryDiscordChannels.model_rebuild()
QueryDiscordChannelsDiscordChannels.model_rebuild()
