# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryMicrosoftCalendars(BaseModel):
    microsoft_calendars: Optional["QueryMicrosoftCalendarsMicrosoftCalendars"] = Field(
        alias="microsoftCalendars"
    )


class QueryMicrosoftCalendarsMicrosoftCalendars(BaseModel):
    results: Optional[
        List[Optional["QueryMicrosoftCalendarsMicrosoftCalendarsResults"]]
    ]


class QueryMicrosoftCalendarsMicrosoftCalendarsResults(BaseModel):
    calendar_name: Optional[str] = Field(alias="calendarName")
    calendar_id: Optional[str] = Field(alias="calendarId")


QueryMicrosoftCalendars.model_rebuild()
QueryMicrosoftCalendarsMicrosoftCalendars.model_rebuild()
