# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountMedicalGuidelines(BaseModel):
    count_medical_guidelines: Optional[
        "CountMedicalGuidelinesCountMedicalGuidelines"
    ] = Field(alias="countMedicalGuidelines")


class CountMedicalGuidelinesCountMedicalGuidelines(BaseModel):
    count: Optional[Any]


CountMedicalGuidelines.model_rebuild()
