# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryNotionDatabases(BaseModel):
    notion_databases: Optional["QueryNotionDatabasesNotionDatabases"] = Field(
        alias="notionDatabases"
    )


class QueryNotionDatabasesNotionDatabases(BaseModel):
    results: Optional[List[Optional["QueryNotionDatabasesNotionDatabasesResults"]]]


class QueryNotionDatabasesNotionDatabasesResults(BaseModel):
    name: Optional[str]
    identifier: Optional[str]


QueryNotionDatabases.model_rebuild()
QueryNotionDatabasesNotionDatabases.model_rebuild()
