# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountMedicalDevices(BaseModel):
    count_medical_devices: Optional["CountMedicalDevicesCountMedicalDevices"] = Field(
        alias="countMedicalDevices"
    )


class CountMedicalDevicesCountMedicalDevices(BaseModel):
    count: Optional[Any]


CountMedicalDevices.model_rebuild()
