# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryDiscordGuilds(BaseModel):
    discord_guilds: Optional["QueryDiscordGuildsDiscordGuilds"] = Field(
        alias="discordGuilds"
    )


class QueryDiscordGuildsDiscordGuilds(BaseModel):
    results: Optional[List[Optional["QueryDiscordGuildsDiscordGuildsResults"]]]


class QueryDiscordGuildsDiscordGuildsResults(BaseModel):
    guild_name: Optional[str] = Field(alias="guildName")
    guild_id: Optional[str] = Field(alias="guildId")


QueryDiscordGuilds.model_rebuild()
QueryDiscordGuildsDiscordGuilds.model_rebuild()
