# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryLinearProjects(BaseModel):
    linear_projects: Optional["QueryLinearProjectsLinearProjects"] = Field(
        alias="linearProjects"
    )


class QueryLinearProjectsLinearProjects(BaseModel):
    results: Optional[List[str]]


QueryLinearProjects.model_rebuild()
